#include <avr/io.h>
#include <avr/interrupt.h>
#define F_CPU 16000000

void init_adc(){ 
	ADCSRA |= ((1<<ADPS2)|(1<<ADPS1)|(1<<ADPS0));    //16Mhz/128 = 125Khz the ADC reference clock
	ADMUX |= (1<<REFS0);                //Voltage reference from Avcc (5v)
	ADCSRA |= (1<<ADEN);                //Turn on ADC
	ADCSRA |= (1<<ADSC);                //Do an initial conversion because this one is the slowest and to ensure that everything is up and running
}

int read_adc_bw(int chn){	//Function to read an arbitrary analogic channel/pin
	int adc_value, temp;

	ADMUX &= ~((1<<MUX0)|(1<<MUX2)|(1<<MUX1));
	switch (chn){
		case 1: ADMUX |= (1<<MUX0); break;
		case 2: ADMUX |= (1<<MUX1);break;
		case 3: ADMUX |= (1<<MUX1)|(1<<MUX0);break;
		case 4: ADMUX |= (1<<MUX2);break;
		case 5: ADMUX |= (1<<MUX0)|(1<<MUX2);break;
		case 6: ADMUX |= (1<<MUX1)|(1<<MUX2);break;
		case 7: ADMUX |= (1<<MUX0)|(1<<MUX2)|(1<<MUX1);break;
		default: break;
	}
	ADCSRA |= (1<<ADSC);                //Starts a new conversion
	while(!bit_is_set(ADCSRA,ADIF));             //Wait until the conversion is done: until ADIF from ADCSRA is set to 1
	temp = ADCL; 
	adc_value = (ADCH<<8); 
	adc_value |= temp;

	return ADCW;                    //Returns the ADC value of the chosen channel
}

void init_timer() {
	DDRD |= (1 << PD0) | (1 << PD2);

	TCCR1A |= (1 << WGM11) | (1 << COM1B1) | (1 << COM1A1);
	TCCR1B |= (1 << WGM12) | (1 << WGM13) | (1 << CS12);
	
	ICR1 = 1000;
}
 
int main(void)
{
	unsigned int value[8];
	int i;
	
	
	// pini enable setati ca output
	DDRD |= (1 << PD1) | (1 << PD3);
	
	// initializare timer
	init_timer();

	// adc init
	init_adc();
	
	while (1)
	{
		for(i=0;i<8;i++)
			value[i] = read_adc_bw(i);
		if (value[0]>30 || value[1]>50 || value[2] > 75 ) { // daca bitul corespunzator PD6 este 0
			OCR1B = 0.01 * ICR1;
			OCR1A = 0 * ICR1;
			PORTD |= (1 << PD3);
			PORTD &= ~(1 << PD1);
		}
		else
		if (value[7]>30 || value[6]>50 || value[5] > 75 ) {
			OCR1B = 0 * ICR1;
			OCR1A = 0.01 * ICR1;
			PORTD |= (1 << PD1);
			PORTD &= ~(1 << PD3);
		}
		else
		if (value[4] > 700 || value[3] > 700) {
			OCR1B = 1 * ICR1;
			OCR1A = 1 * ICR1;
			PORTD &= ~((1 << PD1) | (1 << PD3));
		}
	}  
	return 0;
}